@@ -59,7 +59,7 @@ class Instrument:
 	def play(self, state):
 		if not(self.midi_set) and 'midi_instr' in self.params:
 			if not self.no_fluidsynth:
-				fluidsynth.midi.set_instrument(self.params["channel"], self.params["midi_instr"])
+				fluidsynth.set_instrument(self.params["channel"], self.params["midi_instr"])
 			self.midi_set = True
 			i = MidiInstrument()
 			i.instrument_nr = self.params["midi_instr"]
@@ -88,7 +88,8 @@ class Instrument:
 			v = self.generate_velocity(state)
 			if n != None:
 				for note in n:
-					note.dynamics["velocity"] = int(v)
+					note.velocity = int(v)
+					note.channel = self.params["channel"]
 
 				# Record played notes in a Track
 				if self.last_tick != (state["iterations"], state["tick"]):
@@ -98,7 +99,7 @@ class Instrument:
 
 				if not self.no_fluidsynth:
 					fluidsynth.play_NoteContainer(n,
-						v,self.params["channel"])
+						self.params["channel"], v)
 				self.last_chan = self.params["channel"]
 				self.playing += n
 				self.last_played = n
@@ -106,7 +107,7 @@ class Instrument:
 					state["paint_function"](n, self.params["channel"])
 			else:
 				if len(self.bar) > 0:
-					if len(self.bar) > 0:
+					if self.bar[-1][1] is None:
 						i = 1 / (1.0 / state["resolution"] + \
 							1.0 / self.bar[-1][1])
 						self.bar[-1][1] = i
