@@ -142,17 +142,14 @@ class Sequencer:
 
 	def output_midi(self):
 		c = Composition()
-		chan = []
 		print 
 		print "Writing MIDI file %s..." % self.output_file
 		for s in self.instruments:
 			if hasattr(s, 'bar'):
 				s.track + s.bar
 			c.add_track(s.track)
-			chan.append(s.last_chan)
 		
-		MidiFileOut.write_Composition(self.output_file, chan, 
-				c, self.bpm , 0)
+		MidiFileOut.write_Composition(self.output_file, c, self.bpm , 0)
 
 
 	def replace_scale_note(self, note):
